/*
 * Copyright (c) 2016 Ian Sutton <ian@kremlin.cc>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */


/* RAM segments, global context */
#define PRU0_DRAM			0x00000
#define PRU1_DRAM			0x02000
#define PRUx_SHRRAM			0x10000
#define PRU0_IRAM			0x34000
#define PRU1_IRAM			0x38000

#define PRU_RAM_SIZE			0x02000
#define PRU_SHR_SIZE			0x03000

/* register groups, global context */
#define PRUx_INTC			0x20000
#define PRU0_CTRL			0x22000
#define PRU1_CTRL			0x24000
#define PRU0_DBG			0x22400
#define PRU1_DBG			0x24400
#define PRUx_CFG			0x26000
#define PRUx_UART			0x28000
#define PRUx_IEP			0x2e000
#define PRUx_ECAP			0x30000

/* control registers */
#define PRUx_CTRL_PCTR_RST_VAL_SHAMT	16
#define PRUx_CTRL_PCTR_RST_VAL_MASK	(16 << PRUx_CTRL_PCTR_RST_VAL_SHAMT)
#define PRUx_CTRL_RUNSTATE		(1 << 15)
#define PRUx_CTRL_SINGLE_STEP		(1 << 8)
#define PRUx_CTRL_CTR_EN		(1 << 3)
#define PRUx_CTRL_SLEEPING		(1 << 2)
#define PRUx_CTRL_EN			(1 << 1)
#define PRUx_CTRL_SOFT_RST_N		(1 << 0)

#define PRUx_CTRL_STS			0x04
#define PRUx_CTRL_STS_PCTR_SHAMT	0
#define PRUx_CTRL_SYS_PCTR_MASK		(16 << PRUx_SYS_PCTR_SHAMT)

#define PRUx_CTRL_WAKEUP_EN		0x08
#define PRUx_CTRL_CYCLE_OFST		0x0C
#define PRUx_CTRL_STALL_OFST		0x10

/* intr. registers XXX */

/* configuration registers */
#define PRUx_CFG_REVID				0x00

#define PRUx_CFG_SYSCFG				0x04
#define PRUx_CFG_SYSCFG_SUB_MWAIT		(1 << 5)
#define PRUx_CFG_SYSCFG_STANDBY_INIT		(1 << 4)
#define PRUx_CFG_SYSCFG_STANDBY_MODE_SHAMT	2
#define PRUx_CFG_SYSCFG_STANDBY_MODE_MASK	(2 << PRUx_CFG_SYSCFG_STANDBY_MODE_SHAMT)
#define PRUx_CFG_SYSCFG_IDLE_MODE_SHAMT		0
#define PRUx_CFG_SYSCFG_IDLE_MODE_MASK		(2 << PRUx_CFG_SYSCFG_IDLE_MODE_SHAMT)

#define   PRUCTL_PRU0_SEL	0x1
#define   PRUCTL_PRU1_SEL	0x2
#define   PRUCTL_PRU0_EN	0x4
#define   PRUCTL_PRU1_EN	0x8

#define PRUCTL			_IOW('P', 0, int)
#define PRUIRQEN		_IOW('P', 1, int)
#define PRUIRQBLOCK		_IOW('P', 2, int)
#define PRURESET		_IO ('P', 3)

